import { ICellEditorComp, ICellEditorParams } from '@ag-grid-community/core';
import { DatasourceOptions } from '@genesislcap/foundation-comms';
import { FoundationElement } from '@microsoft/fast-foundation';
/**
 * Parameters used to configure {@link MultiselectEditor}
 * @public
 */
export interface MultiselectEditorParams extends ICellEditorParams {
    allOptionsResourceName: string;
    selectedOptionsCallback: (data: any) => Promise<[]>;
    valueField: string;
    labelField: string;
    async: boolean;
    values: any[];
    datasourceOptions: DatasourceOptions[];
}
/**
 * The AG Multiselect Editor element.
 * @public
 * @tagname %%prefix%%-multiselect-editor
 */
export declare class MultiselectEditor extends FoundationElement implements ICellEditorComp {
    params: MultiselectEditorParams;
    selectedOptions: any[];
    init(params: MultiselectEditorParams): void;
    getGui(): HTMLElement;
    destroy(): void;
    refresh(params: MultiselectEditorParams): boolean;
    getValue(): any[];
    isPopup(): boolean;
    changeHandler(event: any): void;
    isCancelBeforeStart(): boolean;
}
/**
 * The AG Select Renderer Styles.
 * @public
 */
export declare const agMultiselectEditorStyles: import("@microsoft/fast-element").ElementStyles;
/**
 * Get a Design System prefixed Select template.
 * @param designSystem - The design system prefix to use. Defaults to 'foundation'.
 * @returns A Select component template prefixed with the correct design system.
 * @public
 */
export declare const getMultiselectEditorTemplate: (designSystem?: string) => import("@microsoft/fast-element").ViewTemplate<MultiselectEditor, any>;
/**
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-multiselect-editor\>
 */
export declare const foundationMultiselectEditor: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<{
    baseName: string;
    styles: import("@microsoft/fast-element").ElementStyles;
    template: import("@microsoft/fast-element").ViewTemplate<MultiselectEditor, any>;
}>) => import("@microsoft/fast-foundation").FoundationElementRegistry<{
    baseName: string;
    styles: import("@microsoft/fast-element").ElementStyles;
    template: import("@microsoft/fast-element").ViewTemplate<MultiselectEditor, any>;
}, typeof MultiselectEditor>;
//# sourceMappingURL=multiselect.editor.d.ts.map